<?php

namespace App\Command\Migration;

use App\Entity\Client;
use App\Entity\OrganizationalUnit;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\Query\ResultSetMapping;
use Doctrine\Persistence\ManagerRegistry;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name: 'opengnsys:migration:clients', description: 'Migrate clients data')]
class MigrateClientsCommand extends Command
{
    public function __construct(
        private readonly EntityManagerInterface $entityManager,
        private readonly ManagerRegistry $doctrine
    )
    {
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        /** @var EntityManagerInterface $oldDatabaseEntityManager */
        $oldDatabaseEntityManager = $this->doctrine->getManager('og_1');

        $clientRepository = $this->entityManager->getRepository(Client::class);
        $organizationalUnitRepository = $this->entityManager->getRepository(OrganizationalUnit::class);

        /** Obtener los ordenadores de la base de datos antigua **/
        $rsmClients = new ResultSetMapping();
        $rsmClients->addScalarResult('idordenador', 'idordenador');
        $rsmClients->addScalarResult('nombrgrupoordenador', 'nombrgrupoordenador');
        $rsmClients->addScalarResult('comentarios', 'comentarios');
        $pcsQuery = $oldDatabaseEntityManager->createNativeQuery('SELECT idordenador FROM ordenadores', $rsmClients);
        $pcs = $pcsQuery->getResult();

        /** Ordenadores **/
        foreach ($pcs as $pc){
            $newClient = $clientRepository->findOneBy(['migrationId' => $pc->getIdordenador()]);
            if(!$newClient){
                $newClient = new Client();
                $newClient->setMigrationId($pc->getIdordenador());
                $this->entityManager->persist($newClient);
            }
            $newClient->setName($pc->getNombreordenador());
            $newClient->setSerialNumber($pc->getNumserie());
            $newClient->setNetiface($pc->getNetiface());
            $newClient->setNetdriver($pc->getNetdriver());
            $newClient->setMac($pc->getMac());
            $newClient->setIp($pc->getIp());
            //$client->setStatus();
            //$newClient->setCache($pc->getCache());
            //$newClient->setIdproautoexec($pc->getIdproautoexec());
            //$newClient->setOglive($pc->getOglivedir());

            // Netboot

            //$migrationId = ""

            // HardwareProfile
            //$hardwareProfile = $hardwareProfileRepository->findOneBy(['migrationId' => $pc->getIdperfilhard()]);
            //$newClient->setHardwareProfile($hardwareProfile);

            // Menu
            //$menu = $menuRepository->findOneBy(['migrationId' => $pc->getIdmenu()]);
            //$newClient->setMenu($menu);

            // Repository
            //$repository = $repositoryRepository->findOneBy(['migrationId' => $pc->getIdrepositorio()]);
            //$newClient->setRepository($repository);

            // OrganizationalUnit
            $migrationId = $pc->getGrupoid() == 0 ? $pc->getIdaula() : $pc->getGrupoid();
            $organizationalUnit = $organizationalUnitRepository->findOneBy(['migrationId' => $migrationId]);
            $newClient->setOrganizationalUnit($organizationalUnit);

        }
        $this->entityManager->flush();
    }

}